@@ -2,7 +2,7 @@
 
 
 package HiD::Generator;
-$HiD::Generator::VERSION = '1.9';
+$HiD::Generator::VERSION = '1.91';
 use Moose::Role;
 
 use 5.014;
@@ -15,6 +15,18 @@ use feature    qw/ unicode_strings /;
 requires 'generate';
 
 
+sub _create_destination_directory_if_needed {
+  my( $self , $dest ) = @_;
+
+  if ( -e $dest ) {
+    $self->FATAL( "'$dest' exists and is not a directory!" )
+      unless -d $dest;
+  }
+  else { mkdir $dest }
+
+  return 1;
+}
+
 no Moose::Role;
 1;
 
@@ -49,7 +61,7 @@ $site->posts >> and so on.
 
 =head1 VERSION
 
-version 1.9
+version 1.91
 
 =head1 AUTHOR
 
