@@ -2,17 +2,12 @@
 
 
 package HiD::Generator::ArchivePage;
-$HiD::Generator::ArchivePage::VERSION = '1.9';
+$HiD::Generator::ArchivePage::VERSION = '1.91';
 use Moose;
 with 'HiD::Generator';
 
 use HiD::Page;
 
-has 'destination' => (
-  is      => 'ro' ,
-  isa     => 'HiD_DirPath' ,
-);
-
 
 sub generate {
   my( $self , $site ) = @_;
@@ -24,8 +19,9 @@ sub generate {
 
   my $url = $site->config->{archive_page}{url} // 'archive/';
 
-  ### FIXME
-  my $destination = $self->destination // $site->destination;
+  my $destination = $site->config->{archive_page}{destination} // $site->destination;
+
+  $self->_create_destination_directory_if_needed( $destination );
 
   my %archive = (
     by_year       => {} ,
@@ -77,7 +73,8 @@ This Generator produces an archive page of all your posts.
 Enable it by setting the 'archive_page.generate' key in your config to true
 and the 'archive_page.layout' key to the path with the layout for the archive
 page. You can also set 'archive_page.url' to the URL where the page should be
-published to, or let it default to 'archive/'.
+published to, or let it default to the site-wide destination. Finally,
+'archive_page.destination' can be used to set a destination directory.
 
 =head1 METHODS
 
@@ -85,7 +82,7 @@ published to, or let it default to 'archive/'.
 
 =head1 VERSION
 
-version 1.9
+version 1.91
 
 =head1 AUTHOR
 
